.. armsim contribute file

Contribute
==================================

armsim is a very new project, help would be warmly accepted, this is what you
should know about:

* Embedded systems development
* C / assembly programming
* Python programming
* Microprocessor theory

If you would like to help, you can find me here: iamedu at gmail 

